@@ -78,6 +78,10 @@ public class DocLiteralInInterceptor extends AbstractInDatabindingInterceptor {
         }
 
         DepthXMLStreamReader xmlReader = getXMLStreamReader(message);
+        if (xmlReader == null) {
+            LOG.warning("Unable to retrieve XMLStreamReader from message.");
+            return;
+        }
         DataReader<XMLStreamReader> dr = getDataReader(message);
         MessageContentsList parameters = new MessageContentsList();
 
@@ -99,10 +103,8 @@ public class DocLiteralInInterceptor extends AbstractInDatabindingInterceptor {
         }
 
         if (bop == null) {
-            QName startQName = xmlReader == null
-                ? new QName("http://cxf.apache.org/jaxws/provider", "invoke")
-            : xmlReader.getName();
-                bop = getBindingOperationInfo(exchange, startQName, client);
+            QName startQName = xmlReader.getName();
+            bop = getBindingOperationInfo(exchange, startQName, client);
         }
 
         try {
